#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InXM v5'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACMCVD = "".join(chr(c) for c in [76, 73])
ACQFFT = "".join(chr(c) for c in [82, 104, 83, 87, 84, 114, 105, 97, 99, 79, 72])
AFIKJP = 453
AHEOCT = 294
AIIDNI = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 82, 101, 116, 114, 121]
)
AJVDQL = 257
AKQXPI = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 80, 104, 97, 115, 101, 83, 105, 103, 110]
)
AKSTSE = "".join(chr(c) for c in [67, 70, 71, 49, 57])
AMJMAO = 351
AOAWBS = 269
AONPYY = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
ASSAKQ = "".join(chr(c) for c in [75, 54, 48, 48, 85, 112, 108, 111, 97, 100])
ATDZXN = 459
AWBSIR = "".join(
    chr(c) for c in [67, 108, 101, 97, 110, 83, 117, 115, 112, 101, 110, 100, 101, 100]
)
BDJQRJ = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
BFEGZU = "".join(chr(c) for c in [78, 65])
BHZVOA = "".join(chr(c) for c in [67, 70, 71, 51, 48])
BIAMJM = 350
BJEUTO = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
BLKXSJ = "".join(chr(c) for c in [79, 110, 122, 101, 110])
BMJVHF = 263
BQFYLJ = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
BQNRXC = "".join(chr(c) for c in [67, 70, 71, 49])
BQSNQL = "".join(
    chr(c) for c in [70, 114, 101, 113, 68, 101, 116, 101, 99, 69, 114, 114]
)
BSIRYX = 279
BSKSOK = "".join(chr(c) for c in [79, 70, 70])
BSSUHB = "".join(
    chr(c)
    for c in [
        82,
        104,
        72,
        101,
        97,
        116,
        101,
        114,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
    ]
)
BVWVUB = 319
BWJYKL = "".join(chr(c) for c in [78, 69, 87])
BXIBHZ = 476
BXTIAC = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
BXYBQS = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
BYGDSB = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
CBFEGZ = "".join(chr(c) for c in [70, 73, 88])
CCPQIP = "".join(chr(c) for c in [66, 76])
CGETIX = 470
CHWDAF = 451
CPQIPO = "".join(chr(c) for c in [67, 80])
CQBMJV = 261
CQFFTT = "".join(chr(c) for c in [82, 104, 72, 119, 84, 114, 105, 97, 99, 79, 72])
CRTFMN = "".join(chr(c) for c in [54, 52, 75])
CTHBSK = 298
CVDSSR = 256
CVYYPI = "".join(chr(c) for c in [72, 50])
CWAONP = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
CXQIEF = "".join(chr(c) for c in [79, 85, 84, 50, 65, 82, 101, 97, 100])
DAFIKJ = "".join(chr(c) for c in [67, 70, 71, 53])
DGKEAK = "".join(chr(c) for c in [67, 70, 71, 49, 55])
DJQRJJ = "".join(chr(c) for c in [105, 110, 88, 77])
DNIBXT = "".join(chr(c) for c in [82, 104, 72, 114, 72, 76])
DQLAII = "".join(chr(c) for c in [82, 104, 76, 111, 119, 70, 108, 111])
DSBDJQ = "".join(chr(c) for c in [77, 73, 65])
DUBSSU = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
DZXNQT = 460
EAKSTS = 466
ECVYYP = "".join(chr(c) for c in [72, 49])
EFJTAC = "".join(chr(c) for c in [80, 52])
EFXQGL = "".join(chr(c) for c in [79, 85, 84, 51, 65, 82, 101, 97, 100])
EJNIBX = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
EKCWAO = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
EKVKZI = "".join(chr(c) for c in [83, 117, 112, 112, 108, 121, 69, 114, 114])
ELHBQN = 347
EMCGET = 469
EOCTHB = 296
ETIXQV = 471
EUTOPH = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
EXLSXU = "".join(chr(c) for c in [85, 100, 76, 105])
FCRTFM = "".join(chr(c) for c in [52, 56, 75])
FEFJTA = "".join(chr(c) for c in [80, 51])
FEGZUQ = "".join(chr(c) for c in [83, 67, 65, 78])
FFTTID = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
FIKJPU = "".join(chr(c) for c in [67, 70, 71, 54])
FJBIAM = 314
FJTACC = 6
FMNHTB = "".join(chr(c) for c in [85, 76])
FTHECV = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
FTSIFJ = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
FTTIDU = "".join(chr(c) for c in [82, 104, 83, 119, 75, 105, 110, 84, 101, 109, 112])
FWRKIN = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
FXQGLR = 288
FYLJUI = "".join(chr(c) for c in [78, 79])
FZDGKE = "".join(chr(c) for c in [67, 70, 71, 49, 54])
GDSBDJ = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
GETIXQ = "".join(chr(c) for c in [67, 70, 71, 50, 51])
GKEAKS = 465
GLRAHE = "".join(chr(c) for c in [79, 85, 84, 53, 65, 82, 101, 97, 100])
GQPLSP = 316
GSELHB = 346
GTYIYW = 329
GVUNXN = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 118])
GZUQEX = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
HBQNRX = 448
HBSKSO = 275
HBVWVU = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
HBXIBH = "".join(chr(c) for c in [67, 70, 71, 50, 56])
HECVYY = "".join(chr(c) for c in [83, 50])
HEOCTH = "".join(chr(c) for c in [79, 85, 84, 55, 65, 82, 101, 97, 100])
HFTHEC = 353
HIUSOO = "".join(chr(c) for c in [85, 100, 80, 52])
HTBJEU = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
HUGTYI = 328
HUOJRJ = "".join(chr(c) for c in [65, 76, 76])
HWDAFI = "".join(chr(c) for c in [67, 70, 71, 52])
HXEKVK = "".join(chr(c) for c in [70, 117, 115, 101, 49, 69, 114, 114])
HZVOAC = 478
IACQFF = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 79, 72])
IAMJMA = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
IBHZVO = 477
IBXTIA = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
IBXYBQ = "".join(
    chr(c) for c in [75, 105, 110, 80, 117, 114, 103, 101, 65, 99, 116, 105, 118, 101]
)
ICXQIE = 282
IDNIBX = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
IDUBSS = 260
IEFXQG = 286
IFJBIA = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
IGYOUS = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
IHBXIB = 475
IIDNIB = "".join(chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 84, 101, 109, 112])
IJUGSE = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 118])
IKFWRK = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
IKJPUN = 454
ILXWAJ = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
INEJNI = "".join(chr(c) for c in [80, 117, 109, 112, 82, 117, 110])
IPIVLA = "".join(chr(c) for c in [76, 101, 97, 114, 110, 105, 110, 103])
IPOUYN = "".join(chr(c) for c in [76, 49, 50, 48])
IRYXBQ = "".join(chr(c) for c in [67, 80, 79, 84])
IUSOOQ = 10
IUXFEF = "".join(chr(c) for c in [76, 79, 87])
IVDNQG = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
IVLASS = "".join(chr(c) for c in [80, 104, 97, 115, 101, 83, 101, 108, 101, 99, 116])
IXQVXO = 472
IYWSKW = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
JBIAMJ = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
JEUTOP = 324
JHIUSO = 11
JIGYOU = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
JJVYFC = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
JMAOAW = 352
JMCBFE = "".join(chr(c) for c in [85, 100, 83, 112, 107, 114, 76, 105, 102, 116])
JNIBXY = 270
JPUNRJ = 455
JQRJJJ = "".join(chr(c) for c in [75, 54, 48, 48])
JRJHIU = "".join(chr(c) for c in [85, 100, 80, 51])
JTACCP = "".join(chr(c) for c in [80, 53])
JUGSEL = 345
JUIKFW = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
JUTYEK = "".join(chr(c) for c in [85, 100, 86, 83, 80, 51])
JVDQLA = "".join(
    chr(c)
    for c in [82, 104, 78, 111, 116, 69, 110, 111, 117, 103, 104, 72, 101, 97, 116]
)
JVHFTH = 256
JVYFCR = 322
JWMNZM = "".join(chr(c) for c in [86, 115, 112, 49, 77, 105, 110])
JYMOUN = "".join(chr(c) for c in [84, 118, 76, 105, 102, 116])
JZTATD = "".join(chr(c) for c in [67, 70, 71, 49, 48])
KCWAON = 359
KEAKST = "".join(chr(c) for c in [67, 70, 71, 49, 56])
KFWRKI = 272
KINEJN = 349
KJPUNR = "".join(chr(c) for c in [67, 70, 71, 55])
KLGQPL = 308
KMLOIJ = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 70, 117, 108, 108]
)
KPHUOJ = 2
KQXPIC = 300
KSOKPH = "".join(chr(c) for c in [72, 73])
KSTSEM = 467
KVKZIL = "".join(chr(c) for c in [83, 99, 97, 110, 69, 114, 114])
KWIVDN = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
KXSJWM = 274
KZILXW = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
LAIIDN = 258
LASSAK = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
LGQPLS = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
LHBQNR = "".join(chr(c) for c in [67, 70, 71, 48])
LIUXFE = "".join(chr(c) for c in [72, 73, 71, 72])
LKXSJW = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121])
LNMHXE = "".join(
    chr(c) for c in [76, 101, 97, 114, 110, 80, 104, 97, 115, 101, 69, 114, 114]
)
LOIJUG = "".join(chr(c) for c in [75, 54, 48, 48, 73, 68])
LRAHEO = 292
LSPFTS = 310
LSXUJU = "".join(chr(c) for c in [77, 69, 68])
LXWAJV = "".join(chr(c) for c in [114, 72, 73, 100])
MAOAWB = "".join(chr(c) for c in [80, 117, 114, 103, 101])
MCBFEG = "".join(chr(c) for c in [85, 100, 70, 98])
MCGETI = "".join(chr(c) for c in [67, 70, 71, 50, 50])
MFZDGK = 463
MHXEKV = "".join(chr(c) for c in [70, 117, 115, 101, 50, 69, 114, 114])
MJIGYO = 348
MJMAOA = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
MJVHFT = "".join(chr(c) for c in [72, 111, 117, 114, 115])
MLOIJU = 341
MNHTBJ = "".join(chr(c) for c in [67, 69])
MNZMJI = "".join(chr(c) for c in [86, 83, 80, 51, 70, 114, 111, 110, 116])
MOUNBL = "".join(chr(c) for c in [85, 80])
NBLKXS = "".join(chr(c) for c in [83, 97, 110, 105])
NEJNIB = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
NIBXTI = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
NIBXYB = "".join(chr(c) for c in [67, 111, 111, 108, 105, 110, 103, 68, 111, 119, 110])
NKMLOI = 339
NMHXEK = "".join(chr(c) for c in [70, 117, 115, 101, 51, 69, 114, 114])
NPYYLI = "".join(chr(c) for c in [85, 100, 68, 114, 97, 105, 110])
NQGVUN = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 73, 68])
NQLNMH = "".join(
    chr(c)
    for c in [
        67,
        111,
        110,
        116,
        97,
        99,
        116,
        111,
        114,
        67,
        111,
        105,
        108,
        70,
        97,
        105,
        108,
        69,
        114,
        114,
    ]
)
NQTMFZ = "".join(chr(c) for c in [67, 70, 71, 49, 52])
NRJZTA = "".join(chr(c) for c in [67, 70, 71, 57])
NRSJMC = 8
NRXCHW = "".join(chr(c) for c in [67, 70, 71, 50])
NXNKML = 338
NZMJIG = 302
OAWBSI = "".join(chr(c) for c in [67, 108, 101, 97, 110])
OCTHBS = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 82, 101, 97, 100])
OIHBXI = "".join(chr(c) for c in [67, 70, 71, 50, 55])
OIJUGS = 343
OJRJHI = 12
OKPHUO = 14
ONPYYL = 361
OOQNRS = "".join(chr(c) for c in [85, 100, 66, 76])
OPHUGT = 327
OQNRSJ = "".join(chr(c) for c in [79, 78])
OUSPBW = 307
OUYNQJ = 7
PBWJYK = "".join(chr(c) for c in [83, 84, 65, 82, 84])
PFTSIF = 311
PHUGTY = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
PHUOJR = 4
PICXQI = "".join(chr(c) for c in [79, 85, 84, 49, 66, 82, 101, 97, 100])
PIPIVL = "".join(chr(c) for c in [76, 101, 97, 114, 110, 70, 97, 105, 108])
PIVLAS = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 83, 101, 108, 101, 99, 116]
)
PLSPFT = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        79,
        110,
        122,
        101,
        110,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
POUYNQ = "".join(chr(c) for c in [70, 65, 78])
PQIPOU = "".join(chr(c) for c in [79, 51])
PUNRJZ = "".join(chr(c) for c in [67, 70, 71, 56])
PYYLIU = 362
QBMJVH = "".join(chr(c) for c in [82, 104, 84, 114, 105, 97, 99, 84, 101, 109, 112])
QEXLSX = 0
QFFTTI = "".join(chr(c) for c in [82, 104, 72, 114, 75, 105, 110])
QFYLJU = 268
QGLRAH = 290
QGVUNX = 335
QIEFXQ = "".join(chr(c) for c in [79, 85, 84, 50, 66, 82, 101, 97, 100])
QIPOUY = 3
QJYMOU = "".join(chr(c) for c in [65, 108, 119, 97, 121, 79, 110])
QLAIID = "".join(chr(c) for c in [82, 104, 68, 117, 116, 121, 69, 114, 114])
QLNMHX = "".join(
    chr(c)
    for c in [
        78,
        111,
        72,
        101,
        97,
        116,
        101,
        114,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
        69,
        114,
        114,
    ]
)
QNRXCH = 449
QPLSPF = "".join(chr(c) for c in [79, 110, 122, 101, 110, 65, 99, 99, 101, 115, 115])
QRJJJV = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
QSNQLN = 277
QTMFZD = 462
QVXOIH = 473
QXPICX = "".join(chr(c) for c in [79, 85, 84, 49, 65, 82, 101, 97, 100])
RAHEOC = "".join(chr(c) for c in [79, 85, 84, 54, 65, 82, 101, 97, 100])
RJJJVY = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
RJZTAT = 457
RKINEJ = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
RSJMCB = "".join(chr(c) for c in [85, 100, 84, 118, 76, 105, 102, 116])
RXCHWD = 450
RYXBQF = "".join(chr(c) for c in [68, 114, 97, 105, 110, 110, 105, 110, 103])
SBDJQR = "".join(chr(c) for c in [68, 74, 83, 52])
SELHBQ = "".join(chr(c) for c in [75, 54, 48, 48, 80, 114, 111, 116, 111, 99, 111, 108])
SEMCGE = "".join(chr(c) for c in [67, 70, 71, 50, 49])
SIFJBI = 313
SIRYXB = "".join(chr(c) for c in [70, 105, 108, 116, 79, 84])
SJMCBF = 5
SJWMNZ = 301
SKSOKP = "".join(chr(c) for c in [76, 79])
SKWIVD = 333
SNQLNM = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
SOOQNR = 9
SPBWJY = "".join(chr(c) for c in [83, 84, 79, 80])
SPFTSI = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 79, 110, 122, 101, 110, 68, 117, 114]
)
SSAKQX = "".join(chr(c) for c in [80, 111, 119, 101, 114, 117, 112])
SSUHBV = "".join(
    chr(c)
    for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107, 82, 101, 97, 100, 121]
)
STSEMC = "".join(chr(c) for c in [67, 70, 71, 50, 48])
SUHBVW = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
TACCPQ = 355
TATDZX = "".join(chr(c) for c in [67, 70, 71, 49, 49])
TBJEUT = 323
TDZXNQ = "".join(chr(c) for c in [67, 70, 71, 49, 50])
TFMNHT = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
THBSKS = "".join(chr(c) for c in [85, 100, 80, 49])
THECVY = "".join(chr(c) for c in [83, 49])
TIACQF = 259
TIDUBS = "".join(
    chr(c)
    for c in [82, 104, 72, 101, 97, 116, 101, 114, 68, 105, 115, 97, 98, 108, 101, 100]
)
TIXQVX = "".join(chr(c) for c in [67, 70, 71, 50, 52])
TMFZDG = "".join(chr(c) for c in [67, 70, 71, 49, 53])
TOPHUG = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
TSEMCG = 468
TSIFJB = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
TTIDUB = "".join(chr(c) for c in [82, 104, 72, 87, 75, 105, 110])
TYEKCW = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
TYIYWS = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
UBSSUH = "".join(chr(c) for c in [82, 104, 70, 108, 111, 67, 104, 101, 99, 107])
UBYGDS = 321
UGSELH = "".join(chr(c) for c in [75, 54, 48, 48, 82, 101, 108])
UGTYIY = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
UHBVWV = 317
UIKFWR = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
UJUTYE = 303
UNBLKX = "".join(chr(c) for c in [83, 112, 107, 114, 76, 105, 102, 116])
UNRJZT = 456
UNXNKM = "".join(chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 82, 101, 108])
UOJRJH = "".join(chr(c) for c in [85, 100, 80, 50])
UQEXLS = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116])
USOOQN = "".join(chr(c) for c in [85, 100, 80, 53])
USPBWJ = "".join(chr(c) for c in [73, 68, 76, 69])
UTOPHU = 325
UTYEKC = 304
UYNQJY = "".join(chr(c) for c in [70, 98])
VDNQGV = "".join(chr(c) for c in [70, 117, 108, 108])
VDQLAI = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
VDSSRU = 479
VHFTHE = "".join(chr(c) for c in [77, 101, 110, 117])
VKZILX = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
VLASSA = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
VOACMC = 479
VUBYGD = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
VUNXNK = 337
VWVUBY = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
VXOIHB = "".join(chr(c) for c in [67, 70, 71, 50, 54])
VYFCRT = "".join(chr(c) for c in [49, 54, 75])
VYYPIP = "".join(chr(c) for c in [72, 51])
WAJVDQ = "".join(chr(c) for c in [82, 104, 67, 111, 109, 109, 69, 114, 114])
WAONPY = 360
WBSIRY = "".join(
    chr(c) for c in [67, 108, 101, 97, 110, 83, 117, 115, 112, 101, 110, 100, 85, 68]
)
WDAFIK = 452
WIVDNQ = 357
WJYKLG = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
WMNZMJ = 305
WRKINE = 265
WSKWIV = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
WVUBYG = 320
XBQFYL = 267
XCHWDA = "".join(chr(c) for c in [67, 70, 71, 51])
XEKVKZ = 278
XFEFJT = "".join(chr(c) for c in [80, 50])
XIBHZV = "".join(chr(c) for c in [67, 70, 71, 50, 57])
XLSXUJ = 306
XNKMLO = "".join(
    chr(c) for c in [105, 110, 84, 104, 101, 114, 109, 67, 117, 114, 49, 75, 87]
)
XNQTMF = 461
XOIHBX = 474
XPICXQ = 280
XQGLRA = "".join(chr(c) for c in [79, 85, 84, 52, 65, 82, 101, 97, 100])
XQIEFX = 284
XQVXOI = "".join(chr(c) for c in [67, 70, 71, 50, 53])
XSJWMN = "".join(chr(c) for c in [86, 115, 112, 49, 70, 114, 111, 110, 116])
XTIACQ = "".join(chr(c) for c in [82, 104, 72, 114, 84, 114, 105, 97, 99, 80, 114])
XUJUTY = "".join(chr(c) for c in [85, 100, 86, 83, 80, 49])
XWAJVD = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
XYBQSN = 271
YBQSNQ = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
YEKCWA = 358
YFCRTF = "".join(chr(c) for c in [51, 50, 75])
YGDSBD = "".join(chr(c) for c in [105, 110, 88, 69])
YIYWSK = 331
YKLGQP = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
YLIUXF = 356
YLJUIK = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
YMOUNB = "".join(chr(c) for c in [68, 79, 87, 78])
YNQJYM = 354
YOUSPB = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
YPIPIV = "".join(chr(c) for c in [70, 114])
YWSKWI = 332
YXBQFY = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
YYLIUX = "".join(chr(c) for c in [80, 49])
YYPIPI = "".join(chr(c) for c in [72, 52])
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = 464
ZILXWA = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 49]
)
ZMJIGY = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
ZTATDZ = 458
ZUQEXL = 1
ZVOACM = "".join(chr(c) for c in [67, 70, 71, 51, 49])
ZXNQTM = "".join(chr(c) for c in [67, 70, 71, 49, 51])
ACCPQI = [BSKSOK, LIUXFE]
CMCVDS = [
    YYLIUX,
    XFEFJT,
    FEFJTA,
    EFJTAC,
    JTACCP,
    CCPQIP,
    CPQIPO,
    PQIPOU,
    IPOUYN,
    POUYNQ,
    UYNQJY,
    QJYMOU,
    JYMOUN,
    UNBLKX,
    NBLKXS,
    BLKXSJ,
    LKXSJW,
    XSJWMN,
    JWMNZM,
    MNZMJI,
    ACMCVD,
]
DNQGVU = [IVDNQG, VDNQGV]
EGZUQE = [BSKSOK, CBFEGZ, BFEGZU, FEGZUQ]
GYOUSP = [JIGYOU, IGYOUS]
JJJVYF = [
    BYGDSB,
    YGDSBD,
    GDSBDJ,
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
    RJJJVY,
]
JYKLGQ = [USPBWJ, SPBWJY, PBWJYK, BWJYKL, WJYKLG]
LJUIKF = [FYLJUI, SKSOKP, LSXUJU, KSOKPH, YLJUIK]
MCVDSS = [
    THBSKS,
    UOJRJH,
    JRJHIU,
    HIUSOO,
    USOOQN,
    OOQNRS,
    RSJMCB,
    JMCBFE,
    MCBFEG,
    GZUQEX,
    UQEXLS,
    EXLSXU,
    XUJUTY,
    JUTYEK,
    TYEKCW,
    EKCWAO,
    CWAONP,
    AONPYY,
    NPYYLI,
]
NHTBJE = [FMNHTB, MNHTBJ]
NQJYMO = [BSKSOK, BSKSOK, CBFEGZ, FEGZUQ]
OACMCV = []
OUNBLK = [YMOUNB, MOUNBL]
QNRSJM = [BSKSOK, OQNRSJ]
RJHIUS = [BSKSOK, KSOKPH]
RTFMNH = [VYFCRT, YFCRTF, FCRTFM, CRTFMN]
SAKQXP = [
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    LASSAK,
    ASSAKQ,
    SSAKQX,
]
SOKPHU = [BSKSOK, SKSOKP, KSOKPH]
SXUJUT = [BSKSOK, SKSOKP, LSXUJU, KSOKPH]
UXFEFJ = [BSKSOK, LIUXFE, IUXFEF]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return SJMCBF

    @property
    def begin(self):
        return CVDSSR

    @property
    def end(self):
        return VDSSRU

    @property
    def all_device_keys(self):
        return CMCVDS

    @property
    def user_demand_keys(self):
        return MCVDSS

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoTempStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoByteStructAccessor(self.struct, MJVHFT, JVHFTH, None),
            VHFTHE: GeckoEnumStructAccessor(
                self.struct, VHFTHE, HFTHEC, None, SAKQXP, None, None, None
            ),
            AKQXPI: GeckoByteStructAccessor(self.struct, AKQXPI, KQXPIC, None),
            QXPICX: GeckoWordStructAccessor(self.struct, QXPICX, XPICXQ, None),
            PICXQI: GeckoWordStructAccessor(self.struct, PICXQI, ICXQIE, None),
            CXQIEF: GeckoWordStructAccessor(self.struct, CXQIEF, XQIEFX, None),
            QIEFXQ: GeckoWordStructAccessor(self.struct, QIEFXQ, IEFXQG, None),
            EFXQGL: GeckoWordStructAccessor(self.struct, EFXQGL, FXQGLR, None),
            XQGLRA: GeckoWordStructAccessor(self.struct, XQGLRA, QGLRAH, None),
            GLRAHE: GeckoWordStructAccessor(self.struct, GLRAHE, LRAHEO, None),
            RAHEOC: GeckoWordStructAccessor(self.struct, RAHEOC, AHEOCT, None),
            HEOCTH: GeckoWordStructAccessor(self.struct, HEOCTH, EOCTHB, None),
            OCTHBS: GeckoWordStructAccessor(self.struct, OCTHBS, CTHBSK, None),
            THBSKS: GeckoEnumStructAccessor(
                self.struct, THBSKS, HBSKSO, OKPHUO, SOKPHU, KPHUOJ, PHUOJR, HUOJRJ
            ),
            UOJRJH: GeckoEnumStructAccessor(
                self.struct, UOJRJH, HBSKSO, OJRJHI, SOKPHU, KPHUOJ, PHUOJR, HUOJRJ
            ),
            JRJHIU: GeckoEnumStructAccessor(
                self.struct, JRJHIU, HBSKSO, JHIUSO, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            HIUSOO: GeckoEnumStructAccessor(
                self.struct, HIUSOO, HBSKSO, IUSOOQ, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            USOOQN: GeckoEnumStructAccessor(
                self.struct, USOOQN, HBSKSO, SOOQNR, RJHIUS, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, HBSKSO, NRSJMC, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, HBSKSO, SJMCBF, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            JMCBFE: GeckoEnumStructAccessor(
                self.struct, JMCBFE, HBSKSO, PHUOJR, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, HBSKSO, KPHUOJ, EGZUQE, KPHUOJ, PHUOJR, HUOJRJ
            ),
            GZUQEX: GeckoEnumStructAccessor(
                self.struct, GZUQEX, HBSKSO, ZUQEXL, QNRSJM, KPHUOJ, KPHUOJ, HUOJRJ
            ),
            UQEXLS: GeckoBoolStructAccessor(
                self.struct, UQEXLS, HBSKSO, QEXLSX, HUOJRJ
            ),
            EXLSXU: GeckoEnumStructAccessor(
                self.struct, EXLSXU, XLSXUJ, QEXLSX, SXUJUT, None, PHUOJR, HUOJRJ
            ),
            XUJUTY: GeckoByteStructAccessor(self.struct, XUJUTY, UJUTYE, HUOJRJ),
            JUTYEK: GeckoByteStructAccessor(self.struct, JUTYEK, UTYEKC, HUOJRJ),
            TYEKCW: GeckoByteStructAccessor(self.struct, TYEKCW, YEKCWA, HUOJRJ),
            EKCWAO: GeckoByteStructAccessor(self.struct, EKCWAO, KCWAON, HUOJRJ),
            CWAONP: GeckoByteStructAccessor(self.struct, CWAONP, WAONPY, HUOJRJ),
            AONPYY: GeckoByteStructAccessor(self.struct, AONPYY, ONPYYL, HUOJRJ),
            NPYYLI: GeckoBoolStructAccessor(self.struct, NPYYLI, PYYLIU, None, HUOJRJ),
            YYLIUX: GeckoEnumStructAccessor(
                self.struct, YYLIUX, YLIUXF, QEXLSX, UXFEFJ, None, PHUOJR, None
            ),
            XFEFJT: GeckoEnumStructAccessor(
                self.struct, XFEFJT, YLIUXF, KPHUOJ, UXFEFJ, None, PHUOJR, None
            ),
            FEFJTA: GeckoEnumStructAccessor(
                self.struct, FEFJTA, YLIUXF, PHUOJR, UXFEFJ, None, PHUOJR, None
            ),
            EFJTAC: GeckoEnumStructAccessor(
                self.struct, EFJTAC, YLIUXF, FJTACC, UXFEFJ, None, PHUOJR, None
            ),
            JTACCP: GeckoEnumStructAccessor(
                self.struct, JTACCP, TACCPQ, QEXLSX, ACCPQI, None, KPHUOJ, None
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, TACCPQ, ZUQEXL, QNRSJM, None, KPHUOJ, None
            ),
            CPQIPO: GeckoEnumStructAccessor(
                self.struct, CPQIPO, TACCPQ, KPHUOJ, QNRSJM, None, KPHUOJ, None
            ),
            PQIPOU: GeckoEnumStructAccessor(
                self.struct, PQIPOU, TACCPQ, QIPOUY, QNRSJM, None, KPHUOJ, None
            ),
            IPOUYN: GeckoEnumStructAccessor(
                self.struct, IPOUYN, TACCPQ, PHUOJR, QNRSJM, None, KPHUOJ, None
            ),
            POUYNQ: GeckoEnumStructAccessor(
                self.struct, POUYNQ, TACCPQ, OUYNQJ, QNRSJM, None, KPHUOJ, None
            ),
            UYNQJY: GeckoEnumStructAccessor(
                self.struct, UYNQJY, YNQJYM, QEXLSX, NQJYMO, None, PHUOJR, None
            ),
            QJYMOU: GeckoEnumStructAccessor(
                self.struct, QJYMOU, YNQJYM, KPHUOJ, QNRSJM, None, KPHUOJ, None
            ),
            JYMOUN: GeckoEnumStructAccessor(
                self.struct, JYMOUN, YNQJYM, QIPOUY, OUNBLK, None, KPHUOJ, None
            ),
            UNBLKX: GeckoEnumStructAccessor(
                self.struct, UNBLKX, YNQJYM, PHUOJR, OUNBLK, None, KPHUOJ, None
            ),
            NBLKXS: GeckoEnumStructAccessor(
                self.struct, NBLKXS, YNQJYM, SJMCBF, QNRSJM, None, KPHUOJ, None
            ),
            BLKXSJ: GeckoEnumStructAccessor(
                self.struct, BLKXSJ, YNQJYM, FJTACC, QNRSJM, None, KPHUOJ, None
            ),
            LKXSJW: GeckoByteStructAccessor(self.struct, LKXSJW, KXSJWM, None),
            XSJWMN: GeckoByteStructAccessor(self.struct, XSJWMN, SJWMNZ, None),
            JWMNZM: GeckoByteStructAccessor(self.struct, JWMNZM, WMNZMJ, None),
            MNZMJI: GeckoByteStructAccessor(self.struct, MNZMJI, NZMJIG, None),
            ZMJIGY: GeckoEnumStructAccessor(
                self.struct, ZMJIGY, MJIGYO, QEXLSX, GYOUSP, None, KPHUOJ, HUOJRJ
            ),
            YOUSPB: GeckoEnumStructAccessor(
                self.struct, YOUSPB, OUSPBW, None, JYKLGQ, None, None, HUOJRJ
            ),
            YKLGQP: GeckoTimeStructAccessor(self.struct, YKLGQP, KLGQPL, HUOJRJ),
            LGQPLS: GeckoByteStructAccessor(self.struct, LGQPLS, GQPLSP, HUOJRJ),
            QPLSPF: GeckoEnumStructAccessor(
                self.struct, QPLSPF, MJIGYO, ZUQEXL, GYOUSP, None, KPHUOJ, HUOJRJ
            ),
            PLSPFT: GeckoEnumStructAccessor(
                self.struct, PLSPFT, LSPFTS, None, JYKLGQ, None, None, HUOJRJ
            ),
            SPFTSI: GeckoTimeStructAccessor(self.struct, SPFTSI, PFTSIF, HUOJRJ),
            FTSIFJ: GeckoEnumStructAccessor(
                self.struct, FTSIFJ, MJIGYO, KPHUOJ, GYOUSP, None, KPHUOJ, HUOJRJ
            ),
            TSIFJB: GeckoEnumStructAccessor(
                self.struct, TSIFJB, SIFJBI, None, JYKLGQ, None, None, HUOJRJ
            ),
            IFJBIA: GeckoTimeStructAccessor(self.struct, IFJBIA, FJBIAM, HUOJRJ),
            JBIAMJ: GeckoByteStructAccessor(self.struct, JBIAMJ, BIAMJM, HUOJRJ),
            IAMJMA: GeckoByteStructAccessor(self.struct, IAMJMA, AMJMAO, HUOJRJ),
            MJMAOA: GeckoByteStructAccessor(self.struct, MJMAOA, JMAOAW, HUOJRJ),
            MAOAWB: GeckoBoolStructAccessor(self.struct, MAOAWB, AOAWBS, OUYNQJ, None),
            OAWBSI: GeckoBoolStructAccessor(self.struct, OAWBSI, AOAWBS, SJMCBF, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, AOAWBS, PHUOJR, None),
            WBSIRY: GeckoBoolStructAccessor(self.struct, WBSIRY, BSIRYX, QIPOUY, None),
            SIRYXB: GeckoBoolStructAccessor(self.struct, SIRYXB, BSIRYX, QEXLSX, None),
            IRYXBQ: GeckoBoolStructAccessor(self.struct, IRYXBQ, BSIRYX, ZUQEXL, None),
            RYXBQF: GeckoBoolStructAccessor(self.struct, RYXBQF, BSIRYX, OUYNQJ, None),
            YXBQFY: GeckoBoolStructAccessor(self.struct, YXBQFY, XBQFYL, None, None),
            BQFYLJ: GeckoEnumStructAccessor(
                self.struct, BQFYLJ, QFYLJU, None, LJUIKF, None, None, None
            ),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, AOAWBS, QIPOUY, None),
            UIKFWR: GeckoBoolStructAccessor(self.struct, UIKFWR, AOAWBS, KPHUOJ, None),
            IKFWRK: GeckoTempStructAccessor(self.struct, IKFWRK, KFWRKI, None),
            FWRKIN: GeckoTempStructAccessor(self.struct, FWRKIN, WRKINE, None),
            RKINEJ: GeckoBoolStructAccessor(self.struct, RKINEJ, KINEJN, ZUQEXL, None),
            INEJNI: GeckoBoolStructAccessor(self.struct, INEJNI, AOAWBS, ZUQEXL, None),
            NEJNIB: GeckoBoolStructAccessor(self.struct, NEJNIB, AOAWBS, QEXLSX, None),
            EJNIBX: GeckoBoolStructAccessor(self.struct, EJNIBX, JNIBXY, OUYNQJ, None),
            NIBXYB: GeckoBoolStructAccessor(self.struct, NIBXYB, JNIBXY, FJTACC, None),
            IBXYBQ: GeckoBoolStructAccessor(self.struct, IBXYBQ, JNIBXY, SJMCBF, None),
            BXYBQS: GeckoBoolStructAccessor(self.struct, BXYBQS, XYBQSN, QEXLSX, None),
            YBQSNQ: GeckoBoolStructAccessor(self.struct, YBQSNQ, XYBQSN, KPHUOJ, None),
            BQSNQL: GeckoBoolStructAccessor(self.struct, BQSNQL, QSNQLN, FJTACC, None),
            SNQLNM: GeckoBoolStructAccessor(self.struct, SNQLNM, QSNQLN, SJMCBF, None),
            NQLNMH: GeckoBoolStructAccessor(self.struct, NQLNMH, QSNQLN, PHUOJR, None),
            QLNMHX: GeckoBoolStructAccessor(self.struct, QLNMHX, QSNQLN, QIPOUY, None),
            LNMHXE: GeckoBoolStructAccessor(self.struct, LNMHXE, QSNQLN, KPHUOJ, None),
            NMHXEK: GeckoBoolStructAccessor(self.struct, NMHXEK, QSNQLN, ZUQEXL, None),
            MHXEKV: GeckoBoolStructAccessor(self.struct, MHXEKV, QSNQLN, QEXLSX, None),
            HXEKVK: GeckoBoolStructAccessor(self.struct, HXEKVK, XEKVKZ, OUYNQJ, None),
            EKVKZI: GeckoBoolStructAccessor(self.struct, EKVKZI, XEKVKZ, FJTACC, None),
            KVKZIL: GeckoBoolStructAccessor(self.struct, KVKZIL, XEKVKZ, SJMCBF, None),
            VKZILX: GeckoBoolStructAccessor(self.struct, VKZILX, XEKVKZ, PHUOJR, None),
            KZILXW: GeckoBoolStructAccessor(self.struct, KZILXW, XEKVKZ, QIPOUY, None),
            ZILXWA: GeckoBoolStructAccessor(self.struct, ZILXWA, XEKVKZ, KPHUOJ, None),
            ILXWAJ: GeckoBoolStructAccessor(self.struct, ILXWAJ, XEKVKZ, ZUQEXL, None),
            LXWAJV: GeckoBoolStructAccessor(self.struct, LXWAJV, XEKVKZ, QEXLSX, None),
            XWAJVD: GeckoBoolStructAccessor(self.struct, XWAJVD, BSIRYX, PHUOJR, None),
            WAJVDQ: GeckoBoolStructAccessor(self.struct, WAJVDQ, AJVDQL, OUYNQJ, None),
            JVDQLA: GeckoBoolStructAccessor(self.struct, JVDQLA, AJVDQL, QIPOUY, None),
            VDQLAI: GeckoBoolStructAccessor(self.struct, VDQLAI, AJVDQL, KPHUOJ, None),
            DQLAII: GeckoBoolStructAccessor(self.struct, DQLAII, AJVDQL, QEXLSX, None),
            QLAIID: GeckoBoolStructAccessor(self.struct, QLAIID, LAIIDN, OUYNQJ, None),
            AIIDNI: GeckoBoolStructAccessor(self.struct, AIIDNI, LAIIDN, FJTACC, None),
            IIDNIB: GeckoBoolStructAccessor(self.struct, IIDNIB, LAIIDN, SJMCBF, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, LAIIDN, PHUOJR, None),
            DNIBXT: GeckoBoolStructAccessor(self.struct, DNIBXT, LAIIDN, QIPOUY, None),
            NIBXTI: GeckoBoolStructAccessor(self.struct, NIBXTI, LAIIDN, KPHUOJ, None),
            IBXTIA: GeckoBoolStructAccessor(self.struct, IBXTIA, LAIIDN, ZUQEXL, None),
            BXTIAC: GeckoBoolStructAccessor(self.struct, BXTIAC, LAIIDN, QEXLSX, None),
            XTIACQ: GeckoBoolStructAccessor(self.struct, XTIACQ, TIACQF, OUYNQJ, None),
            IACQFF: GeckoBoolStructAccessor(self.struct, IACQFF, TIACQF, FJTACC, None),
            ACQFFT: GeckoBoolStructAccessor(self.struct, ACQFFT, TIACQF, SJMCBF, None),
            CQFFTT: GeckoBoolStructAccessor(self.struct, CQFFTT, TIACQF, PHUOJR, None),
            QFFTTI: GeckoBoolStructAccessor(self.struct, QFFTTI, TIACQF, QIPOUY, None),
            FFTTID: GeckoBoolStructAccessor(self.struct, FFTTID, TIACQF, KPHUOJ, None),
            FTTIDU: GeckoBoolStructAccessor(self.struct, FTTIDU, TIACQF, ZUQEXL, None),
            TTIDUB: GeckoBoolStructAccessor(self.struct, TTIDUB, TIACQF, QEXLSX, None),
            TIDUBS: GeckoBoolStructAccessor(self.struct, TIDUBS, IDUBSS, PHUOJR, None),
            DUBSSU: GeckoBoolStructAccessor(self.struct, DUBSSU, IDUBSS, QIPOUY, None),
            UBSSUH: GeckoBoolStructAccessor(self.struct, UBSSUH, IDUBSS, KPHUOJ, None),
            BSSUHB: GeckoBoolStructAccessor(self.struct, BSSUHB, IDUBSS, ZUQEXL, None),
            SSUHBV: GeckoBoolStructAccessor(self.struct, SSUHBV, IDUBSS, QEXLSX, None),
            SUHBVW: GeckoWordStructAccessor(self.struct, SUHBVW, UHBVWV, None),
            HBVWVU: GeckoByteStructAccessor(self.struct, HBVWVU, BVWVUB, None),
            VWVUBY: GeckoByteStructAccessor(self.struct, VWVUBY, WVUBYG, None),
            VUBYGD: GeckoEnumStructAccessor(
                self.struct, VUBYGD, UBYGDS, None, JJJVYF, None, None, None
            ),
            JJVYFC: GeckoEnumStructAccessor(
                self.struct, JJVYFC, JVYFCR, QEXLSX, RTFMNH, None, PHUOJR, None
            ),
            TFMNHT: GeckoEnumStructAccessor(
                self.struct, TFMNHT, JVYFCR, KPHUOJ, NHTBJE, None, KPHUOJ, None
            ),
            HTBJEU: GeckoByteStructAccessor(self.struct, HTBJEU, TBJEUT, None),
            BJEUTO: GeckoByteStructAccessor(self.struct, BJEUTO, JEUTOP, None),
            EUTOPH: GeckoWordStructAccessor(self.struct, EUTOPH, UTOPHU, None),
            TOPHUG: GeckoByteStructAccessor(self.struct, TOPHUG, OPHUGT, None),
            PHUGTY: GeckoByteStructAccessor(self.struct, PHUGTY, HUGTYI, None),
            UGTYIY: GeckoWordStructAccessor(self.struct, UGTYIY, GTYIYW, None),
            TYIYWS: GeckoByteStructAccessor(self.struct, TYIYWS, YIYWSK, None),
            IYWSKW: GeckoByteStructAccessor(self.struct, IYWSKW, YWSKWI, None),
            WSKWIV: GeckoWordStructAccessor(self.struct, WSKWIV, SKWIVD, None),
            KWIVDN: GeckoEnumStructAccessor(
                self.struct, KWIVDN, WIVDNQ, None, DNQGVU, None, KPHUOJ, HUOJRJ
            ),
            NQGVUN: GeckoWordStructAccessor(self.struct, NQGVUN, QGVUNX, None),
            GVUNXN: GeckoByteStructAccessor(self.struct, GVUNXN, VUNXNK, None),
            UNXNKM: GeckoByteStructAccessor(self.struct, UNXNKM, NXNKML, None),
            XNKMLO: GeckoWordStructAccessor(self.struct, XNKMLO, NKMLOI, None),
            KMLOIJ: GeckoWordStructAccessor(self.struct, KMLOIJ, MLOIJU, None),
        }



#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'MAS-IBC-32K v1'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [52, 52])
AHEOCT = 265
AKQXPI = 260
AONPYY = "".join(chr(c) for c in [50, 54])
ASSAKQ = "".join(chr(c) for c in [72, 73, 71, 72])
BFEGZU = "".join(
    chr(c)
    for c in [80, 117, 114, 103, 101, 68, 101, 108, 97, 121, 84, 105, 109, 101, 114]
)
BLKXSJ = 6
BMJVHF = "".join(chr(c) for c in [85, 115, 101, 114, 67, 104, 114, 111, 109, 97])
BSKSOK = "".join(chr(c) for c in [49, 53])
BWJYKL = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
CBFEGZ = 1
CCPQIP = "".join(chr(c) for c in [52, 54])
CPQIPO = "".join(chr(c) for c in [52, 55])
CQBMJV = 256
CTHBSK = "".join(chr(c) for c in [])
CVYYPI = "".join(chr(c) for c in [83, 67, 65, 78])
CWAONP = "".join(chr(c) for c in [50, 51])
CXQIEF = 262
ECVYYP = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
EFJTAC = "".join(chr(c) for c in [51, 57])
EFXQGL = 0
EGZUQE = "".join(chr(c) for c in [50])
EKCWAO = "".join(chr(c) for c in [50, 49])
EOCTHB = 266
EXLSXU = "".join(chr(c) for c in [56])
FEFJTA = "".join(chr(c) for c in [51, 56])
FEGZUQ = "".join(chr(c) for c in [49])
FJTACC = "".join(chr(c) for c in [52, 49])
FTHECV = "".join(chr(c) for c in [71, 82, 69, 69, 78])
FTSIFJ = "".join(chr(c) for c in [49, 54, 75])
FXQGLR = 2
GLRAHE = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        68,
        114,
        121,
        105,
        110,
        103,
        77,
        105,
        110,
        117,
        116,
        101,
    ]
)
GQPLSP = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
GYOUSP = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
GZUQEX = "".join(chr(c) for c in [51])
HBSKSO = "".join(chr(c) for c in [49, 48])
HECVYY = "".join(chr(c) for c in [80, 85, 82, 80, 76, 69])
HEOCTH = "".join(
    chr(c)
    for c in [85, 115, 101, 114, 68, 114, 121, 105, 110, 103, 68, 101, 108, 97, 121]
)
HFTHEC = "".join(chr(c) for c in [82, 69, 68])
HIUSOO = 267
HUOJRJ = "".join(chr(c) for c in [53, 48])
IAMJMA = "".join(chr(c) for c in [76, 73])
ICXQIE = "".join(
    chr(c)
    for c in [85, 115, 101, 114, 68, 114, 121, 105, 110, 103, 67, 121, 99, 108, 101]
)
IFJBIA = "".join(chr(c) for c in [54, 52, 75])
IGYOUS = 278
IPIVLA = 258
IPOUYN = "".join(chr(c) for c in [53, 49])
IUSOOQ = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
IUXFEF = "".join(chr(c) for c in [51, 52])
IVLASS = 259
JBIAMJ = 4
JHIUSO = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
JIGYOU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
JMAOAW = 285
JMCBFE = "".join(chr(c) for c in [65, 67, 84, 73, 86, 65, 84, 69])
JTACCP = "".join(chr(c) for c in [52, 50])
JUTYEK = "".join(chr(c) for c in [49, 54])
JVHFTH = "".join(chr(c) for c in [79, 70, 70])
JWMNZM = "".join(chr(c) for c in [66, 111, 111, 116, 73, 68])
JYKLGQ = "".join(chr(c) for c in [68, 74, 83, 52])
JYMOUN = "".join(chr(c) for c in [53, 57])
KCWAON = "".join(chr(c) for c in [50, 50])
KLGQPL = "".join(chr(c) for c in [105, 110, 88, 77])
KPHUOJ = "".join(chr(c) for c in [52, 48])
KQXPIC = "".join(chr(c) for c in [85, 115, 101, 114, 71, 101, 121, 115, 97, 105, 114])
KSOKPH = "".join(chr(c) for c in [50, 53])
KXSJWM = 283
LASSAK = "".join(chr(c) for c in [77, 69, 68])
LGQPLS = "".join(chr(c) for c in [75, 54, 48, 48])
LIUXFE = "".join(chr(c) for c in [51, 51])
LKXSJW = "".join(chr(c) for c in [80, 111, 119, 101, 114, 83, 116, 97, 116, 101])
LRAHEO = 264
LSXUJU = "".join(chr(c) for c in [49, 49])
MJIGYO = 276
MJMAOA = 256
MJVHFT = 257
MNZMJI = "".join(chr(c) for c in [66, 111, 111, 116, 82, 101, 118])
MOUNBL = "".join(
    chr(c) for c in [80, 117, 114, 103, 101, 83, 116, 97, 110, 100, 98, 121]
)
NPYYLI = "".join(chr(c) for c in [50, 56])
NQJYMO = "".join(chr(c) for c in [53, 55])
NZMJIG = 274
OCTHBS = "".join(chr(c) for c in [48])
OJRJHI = "".join(chr(c) for c in [54, 48])
OKPHUO = "".join(chr(c) for c in [51, 53])
ONPYYL = "".join(chr(c) for c in [50, 55])
OOQNRS = 271
OQNRSJ = "".join(chr(c) for c in [82, 85, 78])
OUNBLK = "".join(chr(c) for c in [83, 84, 79, 80])
OUSPBW = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
OUYNQJ = "".join(chr(c) for c in [53, 51])
PBWJYK = "".join(chr(c) for c in [105, 110, 88, 69])
PFTSIF = 282
PHUOJR = "".join(chr(c) for c in [52, 53])
PIPIVL = "".join(
    chr(c) for c in [85, 115, 101, 114, 66, 97, 116, 104, 84, 105, 109, 101]
)
PIVLAS = "".join(chr(c) for c in [85, 115, 101, 114, 72, 101, 97, 116, 101, 114, 49])
PLSPFT = "".join(chr(c) for c in [105, 110, 89, 84])
POUYNQ = "".join(chr(c) for c in [53, 50])
PQIPOU = "".join(chr(c) for c in [52, 56])
PYYLIU = "".join(chr(c) for c in [50, 57])
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [55])
QGLRAH = 263
QIEFXQ = "".join(chr(c) for c in [68, 97, 105, 108, 121])
QIPOUY = "".join(chr(c) for c in [52, 57])
QJYMOU = "".join(chr(c) for c in [53, 56])
QNRSJM = "".join(chr(c) for c in [83, 84, 65, 84, 69, 49, 48])
QPLSPF = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
QXPICX = 261
RAHEOC = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        68,
        114,
        121,
        105,
        110,
        103,
        83,
        101,
        99,
        111,
        110,
        100,
    ]
)
RJHIUS = 63
RSJMCB = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 116, 97, 114, 116])
SAKQXP = "".join(chr(c) for c in [85, 115, 101, 114, 72, 101, 97, 116, 101, 114, 50])
SIFJBI = "".join(chr(c) for c in [52, 56, 75])
SJMCBF = "".join(chr(c) for c in [68, 69, 65, 67, 84, 73, 86, 65, 84, 69])
SJWMNZ = 284
SKSOKP = "".join(chr(c) for c in [50, 48])
SOKPHU = "".join(chr(c) for c in [51, 48])
SOOQNR = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 83, 116, 97, 116, 101])
SPBWJY = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
SPFTSI = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
SXUJUT = "".join(chr(c) for c in [49, 50])
TACCPQ = "".join(chr(c) for c in [52, 51])
THBSKS = "".join(chr(c) for c in [53])
THECVY = "".join(chr(c) for c in [66, 76, 85, 69])
TSIFJB = "".join(chr(c) for c in [51, 50, 75])
TYEKCW = "".join(chr(c) for c in [49, 56])
UJUTYE = "".join(chr(c) for c in [49, 52])
UNBLKX = "".join(chr(c) for c in [83, 84, 65, 82, 84])
UOJRJH = "".join(chr(c) for c in [53, 53])
UQEXLS = "".join(chr(c) for c in [54])
USOOQN = 269
USPBWJ = 281
UTYEKC = "".join(chr(c) for c in [49, 55])
UXFEFJ = "".join(chr(c) for c in [51, 54])
UYNQJY = "".join(chr(c) for c in [53, 52])
VHFTHE = "".join(chr(c) for c in [87, 72, 73, 84, 69])
VLASSA = "".join(chr(c) for c in [76, 79, 87])
VYYPIP = "".join(chr(c) for c in [79, 82, 65, 78, 71, 69])
WAONPY = "".join(chr(c) for c in [50, 52])
WJYKLG = "".join(chr(c) for c in [77, 73, 65])
WMNZMJ = 272
XFEFJT = "".join(chr(c) for c in [51, 55])
XLSXUJ = "".join(chr(c) for c in [57])
XPICXQ = "".join(chr(c) for c in [79, 78])
XQGLRA = "".join(
    chr(c) for c in [85, 115, 101, 114, 68, 114, 121, 105, 110, 103, 72, 111, 117, 114]
)
XQIEFX = "".join(chr(c) for c in [65, 102, 116, 101, 114, 66, 97, 116, 104])
XSJWMN = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 76, 111, 99, 107])
XUJUTY = "".join(chr(c) for c in [49, 51])
YEKCWA = "".join(chr(c) for c in [49, 57])
YKLGQP = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
YLIUXF = "".join(chr(c) for c in [51, 50])
YNQJYM = "".join(chr(c) for c in [53, 54])
YOUSPB = 280
YYLIUX = "".join(chr(c) for c in [51, 49])
YYPIPI = "".join(chr(c) for c in [80, 65, 85, 83, 69])
ZCQBMJ = "".join(
    chr(c)
    for c in [
        85,
        115,
        101,
        114,
        66,
        108,
        111,
        119,
        101,
        114,
        73,
        110,
        116,
        101,
        110,
        115,
        105,
        116,
        121,
    ]
)
ZMJIGY = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
ZUQEXL = "".join(chr(c) for c in [52])
AMJMAO = [JHIUSO, IUSOOQ, SOOQNR, RSJMCB, BFEGZU, MOUNBL, LKXSJW, XSJWMN, IAMJMA]
BIAMJM = []
FJBIAM = [FTSIFJ, TSIFJB, SIFJBI, IFJBIA]
IEFXQG = [XQIEFX, QIEFXQ]
JRJHIU = [
    OCTHBS,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    THBSKS,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    HBSKSO,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    BSKSOK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    SKSOKP,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    KSOKPH,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    SOKPHU,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    OKPHUO,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    KPHUOJ,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    PHUOJR,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    HUOJRJ,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    UOJRJH,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    CTHBSK,
    OJRJHI,
]
LSPFTS = [
    SPBWJY,
    PBWJYK,
    BWJYKL,
    WJYKLG,
    JYKLGQ,
    YKLGQP,
    KLGQPL,
    LGQPLS,
    GQPLSP,
    QPLSPF,
    PLSPFT,
]
MCBFEG = [SJMCBF, JMCBFE]
NBLKXS = [OUNBLK, UNBLKX]
NRSJMC = [YYPIPI, OQNRSJ, QNRSJM]
PICXQI = [JVHFTH, XPICXQ]
SSAKQX = [JVHFTH, VLASSA, LASSAK, ASSAKQ]
YMOUNB = [
    OCTHBS,
    FEGZUQ,
    EGZUQE,
    GZUQEX,
    ZUQEXL,
    THBSKS,
    UQEXLS,
    QEXLSX,
    EXLSXU,
    XLSXUJ,
    HBSKSO,
    LSXUJU,
    SXUJUT,
    XUJUTY,
    UJUTYE,
    BSKSOK,
    JUTYEK,
    UTYEKC,
    TYEKCW,
    YEKCWA,
    SKSOKP,
    EKCWAO,
    KCWAON,
    CWAONP,
    WAONPY,
    KSOKPH,
    AONPYY,
    ONPYYL,
    NPYYLI,
    PYYLIU,
    SOKPHU,
    YYLIUX,
    YLIUXF,
    LIUXFE,
    IUXFEF,
    OKPHUO,
    UXFEFJ,
    XFEFJT,
    FEFJTA,
    EFJTAC,
    KPHUOJ,
    FJTACC,
    JTACCP,
    TACCPQ,
    ACCPQI,
    PHUOJR,
    CCPQIP,
    CPQIPO,
    PQIPOU,
    QIPOUY,
    HUOJRJ,
    IPOUYN,
    POUYNQ,
    OUYNQJ,
    UYNQJY,
    UOJRJH,
    YNQJYM,
    NQJYMO,
    QJYMOU,
    JYMOUN,
    OJRJHI,
]
YPIPIV = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return CBFEGZ

    @property
    def begin(self):
        return MJMAOA

    @property
    def end(self):
        return JMAOAW

    @property
    def all_device_keys(self):
        return AMJMAO

    @property
    def user_demand_keys(self):
        return BIAMJM

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, YPIPIV, None, None, QBMJVH
            ),
            PIPIVL: GeckoByteStructAccessor(self.struct, PIPIVL, IPIVLA, QBMJVH),
            PIVLAS: GeckoEnumStructAccessor(
                self.struct, PIVLAS, IVLASS, None, SSAKQX, None, None, QBMJVH
            ),
            SAKQXP: GeckoEnumStructAccessor(
                self.struct, SAKQXP, AKQXPI, None, SSAKQX, None, None, QBMJVH
            ),
            KQXPIC: GeckoEnumStructAccessor(
                self.struct, KQXPIC, QXPICX, None, PICXQI, None, None, None
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, EFXQGL, IEFXQG, None, FXQGLR, QBMJVH
            ),
            XQGLRA: GeckoByteStructAccessor(self.struct, XQGLRA, QGLRAH, QBMJVH),
            GLRAHE: GeckoByteStructAccessor(self.struct, GLRAHE, LRAHEO, QBMJVH),
            RAHEOC: GeckoByteStructAccessor(self.struct, RAHEOC, AHEOCT, QBMJVH),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, EFXQGL, JRJHIU, None, RJHIUS, QBMJVH
            ),
            JHIUSO: GeckoWordStructAccessor(self.struct, JHIUSO, HIUSOO, None),
            IUSOOQ: GeckoWordStructAccessor(self.struct, IUSOOQ, USOOQN, None),
            SOOQNR: GeckoEnumStructAccessor(
                self.struct, SOOQNR, OOQNRS, None, NRSJMC, None, None, None
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, CXQIEF, CBFEGZ, MCBFEG, None, None, None
            ),
            BFEGZU: GeckoEnumStructAccessor(
                self.struct, BFEGZU, CXQIEF, FXQGLR, YMOUNB, None, None, None
            ),
            MOUNBL: GeckoEnumStructAccessor(
                self.struct, MOUNBL, EOCTHB, BLKXSJ, NBLKXS, None, None, None
            ),
            LKXSJW: GeckoEnumStructAccessor(
                self.struct, LKXSJW, KXSJWM, None, PICXQI, None, None, None
            ),
            XSJWMN: GeckoEnumStructAccessor(
                self.struct, XSJWMN, SJWMNZ, None, PICXQI, None, None, None
            ),
            JWMNZM: GeckoWordStructAccessor(self.struct, JWMNZM, WMNZMJ, None),
            MNZMJI: GeckoWordStructAccessor(self.struct, MNZMJI, NZMJIG, None),
            ZMJIGY: GeckoWordStructAccessor(self.struct, ZMJIGY, MJIGYO, None),
            JIGYOU: GeckoWordStructAccessor(self.struct, JIGYOU, IGYOUS, None),
            GYOUSP: GeckoByteStructAccessor(self.struct, GYOUSP, YOUSPB, None),
            OUSPBW: GeckoEnumStructAccessor(
                self.struct, OUSPBW, USPBWJ, None, LSPFTS, None, None, None
            ),
            SPFTSI: GeckoEnumStructAccessor(
                self.struct, SPFTSI, PFTSIF, EFXQGL, FJBIAM, None, JBIAMJ, None
            ),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXE v60'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACQFFT = "".join(chr(c) for c in [65, 109, 80, 109])
AFIKJP = "".join(
    chr(c)
    for c in [
        68,
        101,
        97,
        108,
        101,
        114,
        76,
        111,
        99,
        107,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
AJVDQL = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        110,
        79,
        102,
        102,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
AKQXPI = "".join(chr(c) for c in [79, 117, 116, 50])
AMJMAO = "".join(chr(c) for c in [70, 50])
AONPYY = "".join(chr(c) for c in [72, 105])
ASSAKQ = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
ATDZXN = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
AWBSIR = 84
BFEGZU = 48
BIAMJM = 83
BJEUTO = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
BLKXSJ = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = 88
BQNRXC = "".join(
    chr(c)
    for c in [
        81,
        117,
        105,
        99,
        107,
        79,
        102,
        102,
        75,
        101,
        121,
        69,
        110,
        97,
        98,
        108,
        101,
    ]
)
BQSNQL = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
BSIRYX = 85
BSKSOK = 17
BSSUHB = 4
BVWVUB = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 97, 114, 116]
)
BWJYKL = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
BXTIAC = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
BXYBQS = 4
BYGDSB = 43
CBFEGZ = "".join(chr(c) for c in [65, 117, 120, 84, 105, 109, 101, 79, 117, 116])
CCPQIP = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
CHWDAF = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
CPQIPO = 28
CQBMJV = 0
CQFFTT = "".join(chr(c) for c in [50, 52, 104])
CTHBSK = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
CXQIEF = "".join(chr(c) for c in [79, 117, 116, 53])
DAFIKJ = 46
DGKEAK = "".join(chr(c) for c in [49])
DJQRJJ = "".join(
    chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
)
DNIBXT = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
DNQGVU = "".join(chr(c) for c in [80, 114, 111, 95, 70, 108, 111, 97, 116])
DQLAII = 76
DSBDJQ = "".join(
    chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
)
DZXNQT = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
EAKSTS = "".join(chr(c) for c in [52])
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = 62
EGZUQE = 32
EJNIBX = 106
EKCWAO = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
EKVKZI = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
ELHBQN = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
EUTOPH = "".join(
    chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
)
FCRTFM = "".join(chr(c) for c in [87, 72, 73, 84, 69])
FEFJTA = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
FEGZUQ = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
FFTTID = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
FIKJPU = 47
FJTACC = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
FMNHTB = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 122
FTTIDU = 64
FWRKIN = "".join(chr(c) for c in [70, 49, 76, 105, 110, 101])
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
FYLJUI = 89
FZDGKE = "".join(
    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
)
GDSBDJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
)
GKEAKS = "".join(chr(c) for c in [50])
GLRAHE = 37
GSELHB = "".join(chr(c) for c in [65, 115, 112, 101, 110])
GTYIYW = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
GVUNXN = "".join(chr(c) for c in [80, 68, 67])
GYOUSP = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
GZUQEX = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
HBSKSO = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 39
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = 55
HTBJEU = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
HUGTYI = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
HXEKVK = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
IACQFF = 34
IAMJMA = "".join(chr(c) for c in [70, 49])
IBXYBQ = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
ICXQIE = 15
IDNIBX = 73
IDUBSS = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
IEFXQG = 18
IFJBIA = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
IGYOUS = 68
IIDNIB = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
IJUGSE = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
IKFWRK = "".join(chr(c) for c in [70, 51, 67, 117, 114, 114, 101, 110, 116])
IKJPUN = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
ILXWAJ = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
INEJNI = 105
IPIVLA = "".join(chr(c) for c in [79, 51])
IRYXBQ = 86
IUSOOQ = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
IUXFEF = 60
IVDNQG = "".join(chr(c) for c in [74, 97, 122, 122, 105])
IVLASS = "".join(chr(c) for c in [72, 84, 82])
IYWSKW = "".join(chr(c) for c in [67, 111, 97, 115, 116])
JBIAMJ = "".join(chr(c) for c in [79, 117, 116, 49, 70, 117, 115, 101])
JEUTOP = "".join(chr(c) for c in [72, 121, 100, 114, 111, 112, 111, 111, 108])
JHIUSO = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
JIGYOU = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
JJJVYF = "".join(chr(c) for c in [71, 82, 69, 69, 78])
JJVYFC = "".join(chr(c) for c in [89, 69, 76, 76, 79, 87])
JMAOAW = "".join(chr(c) for c in [76, 105, 110, 101, 49])
JMCBFE = "".join(
    chr(c)
    for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 84, 105, 109, 101, 79, 117, 116]
)
JNIBXY = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
JPUNRJ = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
JQRJJJ = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        67,
        111,
        108,
        111,
        114,
    ]
)
JRJHIU = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
JTACCP = 78
JUGSEL = "".join(chr(c) for c in [68, 101, 108, 117, 120, 101])
JUIKFW = "".join(chr(c) for c in [70, 50, 67, 117, 114, 114, 101, 110, 116])
JUTYEK = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
JVDQLA = 5
JVHFTH = "".join(chr(c) for c in [78, 65])
JVYFCR = "".join(chr(c) for c in [66, 76, 85, 69])
JWMNZM = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
JYKLGQ = "".join(chr(c) for c in [85, 76, 95, 67, 69])
JYMOUN = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
JZTATD = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
KEAKST = "".join(chr(c) for c in [51])
KFWRKI = 100
KINEJN = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
KJPUNR = 121
KLGQPL = "".join(chr(c) for c in [85, 76])
KMLOIJ = "".join(
    chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
)
KPHUOJ = 79
KQXPIC = 13
KSOKPH = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
KVKZIL = 82
KWIVDN = "".join(chr(c) for c in [72, 111, 116, 115, 112, 114, 105, 110, 103])
KXSJWM = "".join(chr(c) for c in [70])
KZILXW = 72
LAIIDN = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
LASSAK = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
LGQPLS = "".join(chr(c) for c in [67, 69])
LHBQNR = "".join(chr(c) for c in [73, 98, 101, 114, 83, 112, 97])
LIUXFE = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
LJUIKF = 98
LKXSJW = 33
LNMHXE = 10
LOIJUG = "".join(
    chr(c) for c in [87, 87, 79, 95, 87, 104, 105, 114, 108, 99, 97, 114, 101]
)
LRAHEO = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
LSPFTS = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
LSXUJU = 27
LXWAJV = 1
MAOAWB = "".join(chr(c) for c in [76, 105, 110, 101, 50])
MCBFEG = 118
MFZDGK = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
MHXEKV = 71
MJIGYO = 66
MJMAOA = "".join(chr(c) for c in [70, 51])
MJVHFT = 12
MLOIJU = "".join(chr(c) for c in [86, 105, 107, 105, 110, 103])
MNHTBJ = "".join(chr(c) for c in [69, 110, 97, 98, 108, 101])
MNZMJI = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
MOUNBL = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
NBLKXS = 1
NEJNIB = "".join(chr(c) for c in [70, 51, 76, 105, 110, 101])
NIBXTI = "".join(chr(c) for c in [83, 108, 97, 118, 101])
NIBXYB = 3
NKMLOI = "".join(
    chr(c) for c in [83, 117, 112, 101, 114, 105, 111, 114, 83, 112, 97, 115]
)
NMHXEK = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
NPYYLI = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
NQGVUN = "".join(chr(c) for c in [77, 65, 65, 88])
NQJYMO = 30
NQLNMH = 8
NQTMFZ = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
NRXCHW = "".join(
    chr(c)
    for c in [
        77,
        111,
        100,
        101,
        75,
        101,
        121,
        65,
        115,
        73,
        110,
        118,
        101,
        114,
        116,
        68,
        105,
        115,
        112,
        108,
        97,
        121,
        75,
        101,
        121,
    ]
)
NXNKML = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
NZMJIG = 35
OAWBSI = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
OCTHBS = 40
OIJUGS = "".join(chr(c) for c in [79, 107, 101, 97, 110, 111, 115])
OJRJHI = 80
OKPHUO = "".join(chr(c) for c in [79, 117, 116, 76, 105])
OOQNRS = 81
OPHUGT = "".join(chr(c) for c in [65, 114, 116, 101, 115, 105, 97, 110])
OQNRSJ = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
OUNBLK = 63
OUSPBW = "".join(chr(c) for c in [78, 105, 103, 104, 116])
OUYNQJ = 29
PBWJYK = 77
PFTSIF = "".join(
    chr(c)
    for c in [
        77,
        105,
        110,
        105,
        109,
        117,
        109,
        73,
        110,
        112,
        117,
        116,
        67,
        117,
        114,
        114,
        101,
        110,
        116,
    ]
)
PHUGTY = "".join(chr(c) for c in [65, 114, 99, 116, 105, 99])
PHUOJR = "".join(chr(c) for c in [76, 73])
PICXQI = "".join(chr(c) for c in [79, 117, 116, 52])
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = 52
POUYNQ = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
PQIPOU = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
PUNRJZ = 123
PYYLIU = 58
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
QFYLJU = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 70, 117, 115, 101])
QGLRAH = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
QGVUNX = "".join(chr(c) for c in [77, 97, 114, 113, 117, 105, 115])
QIEFXQ = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
QIPOUY = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
QJYMOU = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
QLAIID = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
QLNMHX = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
QNRSJM = "".join(chr(c) for c in [79, 119, 110])
QNRXCH = 45
QPLSPF = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
QRJJJV = "".join(chr(c) for c in [79, 70, 70])
QSNQLN = 23
QTMFZD = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
QXPICX = "".join(chr(c) for c in [79, 117, 116, 51])
RAHEOC = 38
RJHIUS = 54
RJJJVY = "".join(chr(c) for c in [82, 69, 68])
RJZTAT = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
RSJMCB = 0
RTFMNH = 8
RXCHWD = "".join(
    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
)
RYXBQF = "".join(chr(c) for c in [79, 117, 116, 53, 70, 117, 115, 101])
SBDJQR = "".join(
    chr(c)
    for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
)
SELHBQ = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
SEMCGE = 60
SIFJBI = 74
SIRYXB = "".join(chr(c) for c in [79, 117, 116, 52, 70, 117, 115, 101])
SJMCBF = 2
SKWIVD = "".join(chr(c) for c in [70, 111, 117, 114, 95, 87, 105, 110, 100])
SNQLNM = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
SOKPHU = 41
SOOQNR = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
SPBWJY = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
SPFTSI = 53
SSAKQX = "".join(chr(c) for c in [65, 85, 88])
SSUHBV = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
SUHBVW = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
SXUJUT = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
TACCPQ = "".join(chr(c) for c in [80, 49])
TBJEUT = 44
TDZXNQ = 124
TFMNHT = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        66,
        97,
        99,
        107,
        108,
        105,
        103,
        104,
        116,
        69,
        100,
        105,
        116,
    ]
)
THBSKS = 42
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
TIDUBS = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
TMFZDG = 126
TOPHUG = "".join(chr(c) for c in [65, 108, 112, 115])
TSIFJB = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
TTIDUB = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
TYEKCW = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
TYIYWS = "".join(
    chr(c)
    for c in [76, 101, 105, 115, 117, 114, 101, 95, 80, 114, 111, 100, 95, 73, 110, 100]
)
UBSSUH = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
UBYGDS = "".join(
    chr(c)
    for c in [
        75,
        101,
        121,
        112,
        97,
        100,
        84,
        104,
        101,
        114,
        97,
        112,
        121,
        83,
        117,
        112,
        112,
        111,
        114,
        116,
    ]
)
UGSELH = "".join(chr(c) for c in [73, 100, 111, 108])
UGTYIY = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 114])
UHBVWV = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
UIKFWR = 99
UNBLKX = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
UNRJZT = "".join(chr(c) for c in [82, 71, 66])
UNXNKM = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
UOJRJH = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
UQEXLS = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
USOOQN = 56
UTOPHU = "".join(chr(c) for c in [87, 101, 108, 108, 105, 115])
UTYEKC = 57
UXFEFJ = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
VDNQGV = "".join(chr(c) for c in [76, 65])
VDQLAI = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
VLASSA = "".join(chr(c) for c in [])
VUBYGD = 7
VUNXNK = "".join(
    chr(c)
    for c in [80, 114, 101, 109, 105, 117, 109, 95, 76, 101, 105, 115, 117, 114, 101]
)
VWVUBY = 6
VYFCRT = "".join(chr(c) for c in [77, 65, 71, 69, 78, 84, 65])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAJVDQ = 3
WAONPY = "".join(chr(c) for c in [76, 111])
WBSIRY = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
WDAFIK = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
WIVDNQ = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
WJYKLG = 26
WMNZMJ = 31
WRKINE = 104
WSKWIV = "".join(chr(c) for c in [68, 121, 110, 97, 115, 116, 121])
WVUBYG = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 111, 112]
)
XBQFYL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 70, 117, 115, 101])
XCHWDA = "".join(
    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
)
XFEFJT = 61
XLSXUJ = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
XNKMLO = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
XNQTMF = 125
XPICXQ = 14
XQGLRA = 36
XQIEFX = 16
XSJWMN = "".join(chr(c) for c in [67])
XTIACQ = 75
XUJUTY = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
XWAJVD = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
XYBQSN = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
YBQSNQ = 6
YEKCWA = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
YFCRTF = "".join(chr(c) for c in [67, 89, 65, 78])
YGDSBD = "".join(
    chr(c)
    for c in [67, 117, 115, 116, 111, 109, 75, 101, 121, 69, 110, 97, 98, 108, 101, 100]
)
YIYWSK = "".join(chr(c) for c in [66, 117, 108, 108, 102, 114, 111, 103])
YKLGQP = 51
YLIUXF = 59
YLJUIK = "".join(chr(c) for c in [70, 49, 67, 117, 114, 114, 101, 110, 116])
YNQJYM = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
YOUSPB = 70
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YWSKWI = "".join(
    chr(c) for c in [68, 105, 109, 101, 110, 115, 105, 111, 110, 95, 111, 110, 101]
)
YXBQFY = 87
YYLIUX = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZDGKEA = 127
ZILXWA = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
ZMJIGY = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
ZTATDZ = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
ZUQEXL = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
ZXNQTM = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
ACCPQI = [JVHFTH, TACCPQ, PIPIVL]
AIIDNI = [QLAIID, LAIIDN]
AKSTSE = [VLASSA, DGKEAK, GKEAKS, KEAKST, EAKSTS]
AOAWBS = [IAMJMA, AMJMAO, MJMAOA, VLASSA, VLASSA, VLASSA, JMAOAW, MAOAWB]
BDJQRJ = [DSBDJQ, SBDJQR]
CRTFMN = [QRJJJV, RJJJVY, JJJVYF, JJVYFC, JVYFCR, VYFCRT, YFCRTF, FCRTFM]
DUBSSU = [TIDUBS, IDUBSS]
EFXQGL = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
]
EXLSXU = [GZUQEX, ZUQEXL, UQEXLS, QEXLSX]
FJBIAM = [QJYMOU, IFJBIA]
GQPLSP = [KLGQPL, LGQPLS]
HBQNRX = [
    BJEUTO,
    JEUTOP,
    EUTOPH,
    UTOPHU,
    TOPHUG,
    OPHUGT,
    PHUGTY,
    HUGTYI,
    UGTYIY,
    GTYIYW,
    TYIYWS,
    YIYWSK,
    IYWSKW,
    YWSKWI,
    WSKWIV,
    SKWIVD,
    KWIVDN,
    WIVDNQ,
    IVDNQG,
    VDNQGV,
    DNQGVU,
    NQGVUN,
    QGVUNX,
    GVUNXN,
    VUNXNK,
    UNXNKM,
    NXNKML,
    XNKMLO,
    NKMLOI,
    KMLOIJ,
    MLOIJU,
    LOIJUG,
    OIJUGS,
    IJUGSE,
    JUGSEL,
    UGSELH,
    GSELHB,
    SELHBQ,
    ELHBQN,
    LHBQNR,
]
HBVWVU = [SUHBVW, UHBVWV]
HUOJRJ = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PHUOJR,
]
HWDAFI = [XCHWDA, CHWDAF, VLASSA, VLASSA]
IBXTIA = [VLASSA, DNIBXT, NIBXTI]
IPOUYN = [PQIPOU, QIPOUY]
KCWAON = [TYEKCW, YEKCWA, EKCWAO]
KSTSEM = [BMJVHF, AKQXPI, QXPICX, PICXQI, CXQIEF, QIEFXQ, HBSKSO, OKPHUO]
NHTBJE = [FMNHTB, MNHTBJ]
NRJZTA = [UNRJZT, FCRTFM]
NRSJMC = [OQNRSJ, QNRSJM]
ONPYYL = [WAONPY, AONPYY]
QFFTTI = [JVHFTH, ACQFFT, CQFFTT]
RKINEJ = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, JMAOAW, MAOAWB]
SAKQXP = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    LASSAK,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    ASSAKQ,
    SSAKQX,
]
SJWMNZ = [KXSJWM, XSJWMN]
SKSOKP = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]
STSEMC = [PHUOJR]
TATDZX = [JZTATD, ZTATDZ]
TSEMCG = []
UJUTYE = [SXUJUT, XUJUTY]
USPBWJ = [QJYMOU, OUSPBW]
UYNQJY = [PIPIVL, TACCPQ]
XEKVKZ = [JVHFTH, SXUJUT, HXEKVK]
YMOUNB = [QJYMOU, JYMOUN]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return SEMCGE

    @property
    def output_keys(self):
        return KSTSEM

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, SAKQXP, None, None, QBMJVH
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, None, SAKQXP, None, None, QBMJVH
            ),
            QXPICX: GeckoEnumStructAccessor(
                self.struct, QXPICX, XPICXQ, None, SAKQXP, None, None, QBMJVH
            ),
            PICXQI: GeckoEnumStructAccessor(
                self.struct, PICXQI, ICXQIE, None, SAKQXP, None, None, QBMJVH
            ),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, XQIEFX, None, SAKQXP, None, None, QBMJVH
            ),
            QIEFXQ: GeckoEnumStructAccessor(
                self.struct, QIEFXQ, IEFXQG, None, EFXQGL, None, None, QBMJVH
            ),
            FXQGLR: GeckoByteStructAccessor(self.struct, FXQGLR, XQGLRA, QBMJVH),
            QGLRAH: GeckoByteStructAccessor(self.struct, QGLRAH, GLRAHE, QBMJVH),
            LRAHEO: GeckoByteStructAccessor(self.struct, LRAHEO, RAHEOC, QBMJVH),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoByteStructAccessor(self.struct, CTHBSK, THBSKS, QBMJVH),
            HBSKSO: GeckoEnumStructAccessor(
                self.struct, HBSKSO, BSKSOK, None, SKSOKP, None, None, QBMJVH
            ),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, QBMJVH),
            OKPHUO: GeckoEnumStructAccessor(
                self.struct, OKPHUO, KPHUOJ, None, HUOJRJ, None, None, None
            ),
            UOJRJH: GeckoByteStructAccessor(self.struct, UOJRJH, OJRJHI, None),
            JRJHIU: GeckoByteStructAccessor(self.struct, JRJHIU, RJHIUS, QBMJVH),
            JHIUSO: GeckoByteStructAccessor(self.struct, JHIUSO, HIUSOO, QBMJVH),
            IUSOOQ: GeckoByteStructAccessor(self.struct, IUSOOQ, USOOQN, QBMJVH),
            SOOQNR: GeckoEnumStructAccessor(
                self.struct, SOOQNR, OOQNRS, RSJMCB, NRSJMC, None, SJMCBF, QBMJVH
            ),
            JMCBFE: GeckoByteStructAccessor(self.struct, JMCBFE, MCBFEG, QBMJVH),
            CBFEGZ: GeckoByteStructAccessor(self.struct, CBFEGZ, BFEGZU, QBMJVH),
            FEGZUQ: GeckoEnumStructAccessor(
                self.struct, FEGZUQ, EGZUQE, None, EXLSXU, None, None, QBMJVH
            ),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, LSXUJU, None, UJUTYE, None, None, QBMJVH
            ),
            JUTYEK: GeckoEnumStructAccessor(
                self.struct, JUTYEK, UTYEKC, None, KCWAON, None, None, QBMJVH
            ),
            CWAONP: GeckoEnumStructAccessor(
                self.struct, CWAONP, OOQNRS, SJMCBF, ONPYYL, None, SJMCBF, QBMJVH
            ),
            NPYYLI: GeckoByteStructAccessor(self.struct, NPYYLI, PYYLIU, QBMJVH),
            YYLIUX: GeckoByteStructAccessor(self.struct, YYLIUX, YLIUXF, QBMJVH),
            LIUXFE: GeckoByteStructAccessor(self.struct, LIUXFE, IUXFEF, QBMJVH),
            UXFEFJ: GeckoByteStructAccessor(self.struct, UXFEFJ, XFEFJT, QBMJVH),
            FEFJTA: GeckoByteStructAccessor(self.struct, FEFJTA, EFJTAC, QBMJVH),
            FJTACC: GeckoEnumStructAccessor(
                self.struct, FJTACC, JTACCP, None, ACCPQI, None, None, QBMJVH
            ),
            CCPQIP: GeckoEnumStructAccessor(
                self.struct, CCPQIP, CPQIPO, None, IPOUYN, None, None, QBMJVH
            ),
            POUYNQ: GeckoEnumStructAccessor(
                self.struct, POUYNQ, OUYNQJ, None, UYNQJY, None, None, QBMJVH
            ),
            YNQJYM: GeckoEnumStructAccessor(
                self.struct, YNQJYM, NQJYMO, None, YMOUNB, None, None, QBMJVH
            ),
            MOUNBL: GeckoByteStructAccessor(self.struct, MOUNBL, OUNBLK, QBMJVH),
            UNBLKX: GeckoTempStructAccessor(self.struct, UNBLKX, NBLKXS, QBMJVH),
            BLKXSJ: GeckoEnumStructAccessor(
                self.struct, BLKXSJ, LKXSJW, None, SJWMNZ, None, None, QBMJVH
            ),
            JWMNZM: GeckoEnumStructAccessor(
                self.struct, JWMNZM, WMNZMJ, None, UYNQJY, None, None, QBMJVH
            ),
            MNZMJI: GeckoByteStructAccessor(self.struct, MNZMJI, NZMJIG, QBMJVH),
            ZMJIGY: GeckoTempStructAccessor(self.struct, ZMJIGY, MJIGYO, QBMJVH),
            JIGYOU: GeckoTempStructAccessor(self.struct, JIGYOU, IGYOUS, QBMJVH),
            GYOUSP: GeckoEnumStructAccessor(
                self.struct, GYOUSP, YOUSPB, None, USPBWJ, None, None, QBMJVH
            ),
            SPBWJY: GeckoByteStructAccessor(self.struct, SPBWJY, PBWJYK, QBMJVH),
            BWJYKL: GeckoByteStructAccessor(self.struct, BWJYKL, WJYKLG, QBMJVH),
            JYKLGQ: GeckoEnumStructAccessor(
                self.struct, JYKLGQ, YKLGQP, None, GQPLSP, None, None, QBMJVH
            ),
            QPLSPF: GeckoByteStructAccessor(self.struct, QPLSPF, PLSPFT, QBMJVH),
            LSPFTS: GeckoByteStructAccessor(self.struct, LSPFTS, SPFTSI, QBMJVH),
            PFTSIF: GeckoByteStructAccessor(self.struct, PFTSIF, FTSIFJ, QBMJVH),
            TSIFJB: GeckoEnumStructAccessor(
                self.struct, TSIFJB, SIFJBI, None, FJBIAM, None, None, QBMJVH
            ),
            JBIAMJ: GeckoEnumStructAccessor(
                self.struct, JBIAMJ, BIAMJM, None, AOAWBS, None, None, QBMJVH
            ),
            OAWBSI: GeckoEnumStructAccessor(
                self.struct, OAWBSI, AWBSIR, None, AOAWBS, None, None, QBMJVH
            ),
            WBSIRY: GeckoEnumStructAccessor(
                self.struct, WBSIRY, BSIRYX, None, AOAWBS, None, None, QBMJVH
            ),
            SIRYXB: GeckoEnumStructAccessor(
                self.struct, SIRYXB, IRYXBQ, None, AOAWBS, None, None, QBMJVH
            ),
            RYXBQF: GeckoEnumStructAccessor(
                self.struct, RYXBQF, YXBQFY, None, AOAWBS, None, None, QBMJVH
            ),
            XBQFYL: GeckoEnumStructAccessor(
                self.struct, XBQFYL, BQFYLJ, None, AOAWBS, None, None, QBMJVH
            ),
            QFYLJU: GeckoEnumStructAccessor(
                self.struct, QFYLJU, FYLJUI, None, AOAWBS, None, None, QBMJVH
            ),
            YLJUIK: GeckoByteStructAccessor(self.struct, YLJUIK, LJUIKF, QBMJVH),
            JUIKFW: GeckoByteStructAccessor(self.struct, JUIKFW, UIKFWR, QBMJVH),
            IKFWRK: GeckoByteStructAccessor(self.struct, IKFWRK, KFWRKI, QBMJVH),
            FWRKIN: GeckoEnumStructAccessor(
                self.struct, FWRKIN, WRKINE, None, RKINEJ, None, None, QBMJVH
            ),
            KINEJN: GeckoEnumStructAccessor(
                self.struct, KINEJN, INEJNI, None, RKINEJ, None, None, QBMJVH
            ),
            NEJNIB: GeckoEnumStructAccessor(
                self.struct, NEJNIB, EJNIBX, None, RKINEJ, None, None, QBMJVH
            ),
            JNIBXY: GeckoByteStructAccessor(self.struct, JNIBXY, NIBXYB, QBMJVH),
            IBXYBQ: GeckoTimeStructAccessor(self.struct, IBXYBQ, BXYBQS, QBMJVH),
            XYBQSN: GeckoTimeStructAccessor(self.struct, XYBQSN, YBQSNQ, QBMJVH),
            BQSNQL: GeckoTimeStructAccessor(self.struct, BQSNQL, QSNQLN, QBMJVH),
            SNQLNM: GeckoTimeStructAccessor(self.struct, SNQLNM, NQLNMH, QBMJVH),
            QLNMHX: GeckoTimeStructAccessor(self.struct, QLNMHX, LNMHXE, QBMJVH),
            NMHXEK: GeckoEnumStructAccessor(
                self.struct, NMHXEK, MHXEKV, None, XEKVKZ, None, None, QBMJVH
            ),
            EKVKZI: GeckoBoolStructAccessor(
                self.struct, EKVKZI, KVKZIL, RSJMCB, QBMJVH
            ),
            VKZILX: GeckoBoolStructAccessor(
                self.struct, VKZILX, KZILXW, SJMCBF, QBMJVH
            ),
            ZILXWA: GeckoBoolStructAccessor(
                self.struct, ZILXWA, KZILXW, RSJMCB, QBMJVH
            ),
            ILXWAJ: GeckoBoolStructAccessor(
                self.struct, ILXWAJ, KZILXW, LXWAJV, QBMJVH
            ),
            XWAJVD: GeckoBoolStructAccessor(
                self.struct, XWAJVD, KZILXW, WAJVDQ, QBMJVH
            ),
            AJVDQL: GeckoBoolStructAccessor(
                self.struct, AJVDQL, KZILXW, JVDQLA, QBMJVH
            ),
            VDQLAI: GeckoEnumStructAccessor(
                self.struct, VDQLAI, DQLAII, None, AIIDNI, None, None, QBMJVH
            ),
            IIDNIB: GeckoEnumStructAccessor(
                self.struct, IIDNIB, IDNIBX, None, IBXTIA, None, None, QBMJVH
            ),
            BXTIAC: GeckoByteStructAccessor(self.struct, BXTIAC, XTIACQ, QBMJVH),
            TIACQF: GeckoEnumStructAccessor(
                self.struct, TIACQF, IACQFF, None, QFFTTI, None, None, QBMJVH
            ),
            FFTTID: GeckoWordStructAccessor(self.struct, FFTTID, FTTIDU, QBMJVH),
            TTIDUB: GeckoEnumStructAccessor(
                self.struct, TTIDUB, OOQNRS, LXWAJV, DUBSSU, None, SJMCBF, QBMJVH
            ),
            UBSSUH: GeckoBoolStructAccessor(
                self.struct, UBSSUH, OOQNRS, BSSUHB, QBMJVH
            ),
            SSUHBV: GeckoEnumStructAccessor(
                self.struct, SSUHBV, OOQNRS, JVDQLA, HBVWVU, None, SJMCBF, QBMJVH
            ),
            BVWVUB: GeckoBoolStructAccessor(
                self.struct, BVWVUB, OOQNRS, VWVUBY, QBMJVH
            ),
            WVUBYG: GeckoBoolStructAccessor(
                self.struct, WVUBYG, OOQNRS, VUBYGD, QBMJVH
            ),
            UBYGDS: GeckoBoolStructAccessor(
                self.struct, UBYGDS, BYGDSB, RSJMCB, QBMJVH
            ),
            YGDSBD: GeckoBoolStructAccessor(
                self.struct, YGDSBD, BYGDSB, LXWAJV, QBMJVH
            ),
            GDSBDJ: GeckoEnumStructAccessor(
                self.struct, GDSBDJ, BYGDSB, SJMCBF, BDJQRJ, None, SJMCBF, QBMJVH
            ),
            DJQRJJ: GeckoEnumStructAccessor(
                self.struct, DJQRJJ, BYGDSB, WAJVDQ, BDJQRJ, None, SJMCBF, QBMJVH
            ),
            JQRJJJ: GeckoEnumStructAccessor(
                self.struct, JQRJJJ, BYGDSB, BSSUHB, CRTFMN, None, RTFMNH, QBMJVH
            ),
            TFMNHT: GeckoEnumStructAccessor(
                self.struct, TFMNHT, BYGDSB, VUBYGD, NHTBJE, None, SJMCBF, QBMJVH
            ),
            BQNRXC: GeckoBoolStructAccessor(
                self.struct, BQNRXC, QNRXCH, RSJMCB, QBMJVH
            ),
            NRXCHW: GeckoBoolStructAccessor(
                self.struct, NRXCHW, QNRXCH, LXWAJV, QBMJVH
            ),
            RXCHWD: GeckoEnumStructAccessor(
                self.struct, RXCHWD, QNRXCH, SJMCBF, HWDAFI, None, BSSUHB, QBMJVH
            ),
            WDAFIK: GeckoByteStructAccessor(self.struct, WDAFIK, DAFIKJ, QBMJVH),
            AFIKJP: GeckoBoolStructAccessor(
                self.struct, AFIKJP, FIKJPU, RSJMCB, QBMJVH
            ),
            IKJPUN: GeckoByteStructAccessor(self.struct, IKJPUN, KJPUNR, QBMJVH),
            JPUNRJ: GeckoEnumStructAccessor(
                self.struct, JPUNRJ, PUNRJZ, RSJMCB, NRJZTA, None, SJMCBF, None
            ),
            RJZTAT: GeckoEnumStructAccessor(
                self.struct, RJZTAT, PUNRJZ, LXWAJV, TATDZX, None, SJMCBF, None
            ),
            ATDZXN: GeckoEnumStructAccessor(
                self.struct, ATDZXN, TDZXNQ, RSJMCB, NRJZTA, None, SJMCBF, None
            ),
            DZXNQT: GeckoEnumStructAccessor(
                self.struct, DZXNQT, TDZXNQ, LXWAJV, TATDZX, None, SJMCBF, None
            ),
            ZXNQTM: GeckoEnumStructAccessor(
                self.struct, ZXNQTM, XNQTMF, RSJMCB, NRJZTA, None, SJMCBF, None
            ),
            NQTMFZ: GeckoEnumStructAccessor(
                self.struct, NQTMFZ, XNQTMF, LXWAJV, TATDZX, None, SJMCBF, None
            ),
            QTMFZD: GeckoEnumStructAccessor(
                self.struct, QTMFZD, TMFZDG, RSJMCB, NRJZTA, None, SJMCBF, None
            ),
            MFZDGK: GeckoEnumStructAccessor(
                self.struct, MFZDGK, TMFZDG, LXWAJV, TATDZX, None, SJMCBF, None
            ),
            FZDGKE: GeckoEnumStructAccessor(
                self.struct, FZDGKE, ZDGKEA, RSJMCB, AKSTSE, None, RTFMNH, None
            ),
        }
